@@ -18,13 +18,19 @@ from .role_awards import RoleAward
 def version_info():
     """Shows the current version, release type, and patch of the library
     - `version` Current version of the library
-    - `releasetype` Either "final" (the PyPI version) or "pre-release" (the Github version)
+    - `releasetype` Either "final" (the PyPI version) or "pre-release" (the GitHub version)
     - `patch` The last significant bug fix
 
     >>> print(discordLevelingSystem.version_info())
     """
     from collections import namedtuple
     VersionInfo = namedtuple('VersionInfo', ['version', 'releasetype', 'patch'])
-    return VersionInfo(version='1.0.2', releasetype='final', patch='1a')
+    return VersionInfo(version='1.1.0', releasetype='final', patch='1a')
 
 __source__ = 'https://github.com/Defxult/discordLevelingSystem'
+__all__ = (
+    'LevelUpAnnouncement',
+    'DiscordLevelingSystem',
+    'MemberData',
+    'RoleAward'
+)
